@@ -25,15 +25,18 @@
 #include "PrinterBehavior.h"
 #include "PrinterOptions.h"
 
+#include "Debug.h"
 #include "KCupsRequest.h"
 
-#include <KConfig>
-#include <KLocale>
+#include <KSharedConfig>
+#include <KConfigGroup>
+#include <KLocalizedString>
 #include <KMessageBox>
-#include <KDebug>
+#include <KWindowConfig>
 
 #include <QList>
 #include <QPointer>
+#include <QPushButton>
 
 Q_DECLARE_METATYPE(QList<int>)
 
@@ -42,9 +45,9 @@ ConfigureDialog::ConfigureDialog(const QString &destName, bool isClass, QWidget
 {
     setFaceType(List);
     setModal(false);
-    setButtons(KDialog::Ok | KDialog::Cancel | KDialog::Apply);
+    setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Apply);
     setWindowTitle(destName);
-    setWindowIcon(KIcon("configure"));
+    setWindowIcon(QIcon::fromTheme("configure"));
     enableButtonApply(false);
     // Needed so we have our dialog size saved
     setAttribute(Qt::WA_DeleteOnClose);
@@ -69,36 +72,36 @@ ConfigureDialog::ConfigureDialog(const QString &destName, bool isClass, QWidget
     if (!request->hasError() && !request->printers().isEmpty()){
         printer = request->printers().first();
     }
-//    kDebug() << "VALUES" << printer.a rgument();
-//    kDebug() << "marker" << values["marker-levels"].value<QList<int> >();
+//    qCDebug(PM_CONFIGURE_PRINTER) << "VALUES" << printer.a rgument();
+//    qCDebug(PM_CONFIGURE_PRINTER) << "marker" << values["marker-levels"].value<QList<int> >();
 
     request->deleteLater();
 
-    //     kDebug() << values;
+    //     qCDebug(PM_CONFIGURE_PRINTER) << values;
     if (printer.type() & CUPS_PRINTER_LOCAL) {
-        kDebug() << "CUPS_PRINTER_LOCAL";
+        qCDebug(PM_CONFIGURE_PRINTER) << "CUPS_PRINTER_LOCAL";
     }
     isClass = printer.isClass();
     bool isRemote = false;
     if (printer.type() & CUPS_PRINTER_REMOTE) {
-        kDebug() << "CUPS_PRINTER_REMOTE";
+        qCDebug(PM_CONFIGURE_PRINTER) << "CUPS_PRINTER_REMOTE";
         isRemote = true;
     }
     if (printer.type() & CUPS_PRINTER_BW) {
-        kDebug() << "CUPS_PRINTER_BW";
+        qCDebug(PM_CONFIGURE_PRINTER) << "CUPS_PRINTER_BW";
     }
     if (printer.type() & CUPS_PRINTER_COLOR) {
-        kDebug() << "CUPS_PRINTER_COLOR";
+        qCDebug(PM_CONFIGURE_PRINTER) << "CUPS_PRINTER_COLOR";
     }
     if (printer.type() & CUPS_PRINTER_MFP) {
-        kDebug() << "CUPS_PRINTER_MFP";
+        qCDebug(PM_CONFIGURE_PRINTER) << "CUPS_PRINTER_MFP";
     }
 
     modifyPrinter->setRemote(isRemote);
     modifyPrinter->setValues(printer);
     page = new KPageWidgetItem(modifyPrinter, i18n("Modify Printer"));
     page->setHeader(i18n("Configure"));
-    page->setIcon(KIcon("dialog-information"));
+    page->setIcon(QIcon::fromTheme("dialog-information"));
     // CONNECT this signal ONLY to the first Page
     connect(modifyPrinter, SIGNAL(changed(bool)), this, SLOT(enableButtonApply(bool)));
     addPage(page);
@@ -109,7 +112,7 @@ ConfigureDialog::ConfigureDialog(const QString &destName, bool isClass, QWidget
         printerOptions = new PrinterOptions(destName, isClass, isRemote, this);
         page = new KPageWidgetItem(printerOptions, i18n("Printer Options"));
         page->setHeader(i18n("Set the Default Printer Options"));
-        page->setIcon(KIcon("view-pim-tasks"));
+        page->setIcon(QIcon::fromTheme("view-pim-tasks"));
         addPage(page);
         connect(modifyPrinter, SIGNAL(ppdChanged()), this, SLOT(ppdChanged()));
         modifyPrinter->setCurrentMake(printerOptions->currentMake());
@@ -120,16 +123,17 @@ ConfigureDialog::ConfigureDialog(const QString &destName, bool isClass, QWidget
     printerBehavior->setValues(printer);
     page = new KPageWidgetItem(printerBehavior, i18n("Banners, Policies and Allowed Users"));
     page->setHeader(i18n("Banners, Policies and Allowed Users"));
-    page->setIcon(KIcon("feed-subscribe"));
+    page->setIcon(QIcon::fromTheme("feed-subscribe"));
     addPage(page);
 
     // connect this after ALL pages were added, otherwise the slot will be called
     connect(this, SIGNAL(currentPageChanged(KPageWidgetItem*,KPageWidgetItem*)),
             SLOT(currentPageChanged(KPageWidgetItem*,KPageWidgetItem*)));
 
-    KConfig config("print-manager");
-    KConfigGroup configureDialog(&config, "ConfigureDialog");
-    restoreDialogSize(configureDialog);
+    KConfigGroup group(KSharedConfig::openConfig("print-manager"), "ConfigureDialog");
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+
+    connect(buttonBox(), SIGNAL(clicked(QAbstractButton*)), this, SLOT(slotButtonClicked(QAbstractButton*)));
 }
 
 void ConfigureDialog::ppdChanged()
@@ -141,9 +145,8 @@ void ConfigureDialog::ppdChanged()
 
 ConfigureDialog::~ConfigureDialog()
 {
-    KConfig config("print-manager");
-    KConfigGroup configureDialog(&config, "ConfigureDialog");
-    saveDialogSize(configureDialog);
+    KConfigGroup group(KSharedConfig::openConfig("print-manager"), "ConfigureDialog");
+    KWindowConfig::saveWindowSize(windowHandle(), group);
 }
 
 void ConfigureDialog::currentPageChanged(KPageWidgetItem *current, KPageWidgetItem *before)
@@ -162,16 +165,17 @@ void ConfigureDialog::currentPageChanged(KPageWidgetItem *current, KPageWidgetIt
     enableButtonApply(currentPage->hasChanges());
 }
 
-void ConfigureDialog::slotButtonClicked(int button)
+void ConfigureDialog::enableButtonApply(bool enable)
+{
+    button(QDialogButtonBox::QDialogButtonBox::Apply)->setEnabled(enable);
+}
+
+void ConfigureDialog::slotButtonClicked(QAbstractButton * pressedButton)
 {
     PrinterPage *page = qobject_cast<PrinterPage *>(currentPage()->widget());
-    if (button == KDialog::Ok) {
+    if (pressedButton == button(QDialogButtonBox::Ok) ||
+        pressedButton == button(QDialogButtonBox::Apply)) {
         page->save();
-        accept();
-    } else if (button == KDialog::Apply) {
-        page->save();
-    } else {
-        KDialog::slotButtonClicked(button);
     }
 }
 
